/*
Peter Blockley 2/10/03

Program for uploading files to G3 phone
*/

#include "phone.h"
#include <stdlib.h>
#include <stdio.h>
#include <process.h>
#include <io.h>
#include <fcntl.h>

int get_file_size(char *file)
{
        //get size of file
        int handle;
        int file_size;

        handle = open(file, O_RDONLY);
        if (handle==-1) return 1;
        file_size=filelength(handle);
        close(handle);
        return file_size;
};

int help()
{
        //output help screen
        printf("Peter Blockley - 2 Oct 2003\n");
        printf("Phone Uploader\n");
        printf("(This program uploads files to a phone)\n\n");
        printf("Usage: uploader <type> <file> <com>\n\n");
        printf("<type> - 1 ringtone\n");
        printf("       - 2 video\n");
        printf("       - 3 misc\n");
        printf("       - 4 audio\n\n");
        printf("<file> - file to upload(eg. song.wma)\n");
        printf("         if file has spaces, use quotations eg(\"song title.mpg\")\n\n");
        printf("<com>  - COM port number(eg. 4)\n");
        printf("         COM port number available, when phone plugged in, from:\n");
        printf("         control panel->system->hardware->device manager->ports->USB OBEX Port\n");
        return 1;
};

int main(int argc, char* argv[])
{
        //define variables
        phone_class me;

        int type;
        int file_size;
        int index;

        int handle;
        long file_length;
        char *str;
        char temp[10];
        char com_num[6];

        char s[_MAX_PATH];
        char drive[_MAX_DRIVE];
        char dir[_MAX_DIR];
        char file_name[_MAX_PATH];
        char file_name1[_MAX_PATH+2];
        char ext[_MAX_EXT];
        char file[_MAX_FNAME+_MAX_EXT];

        char base64_name[_MAX_PATH];
        char base64_name1[_MAX_PATH+2];
        char base64_converter[_MAX_PATH];
        int base64_size;

        //check for number of arguments
        if (argc!=4) return help();

        //check upload type in valid range
        type=atoi(argv[1]);
        if ((type<1)||(type>4))
        {
                printf("Invalid Data Type\n");
                return 1;
        };

        //set COM port
        sprintf(com_num, "COM%d", atoi(argv[3]));
        me.SetCommPort(com_num);

        //get file_name
        _fullpath(file_name, argv[2], _MAX_PATH);
        sprintf(file_name1, "\"%s\"", file_name);
        
        //check for file extension
        _splitpath(file_name,drive,dir, file, ext);
        if (ext[0]==NULL)
        {
                printf("error: File not specified\n");
                return 1;
        };

        //get size of file to upload
        file_size=get_file_size(file_name);
        if (file_size==-1)
        {
                  printf("\nError accessing file\n");
                  return 1;
        };

        //get temp directory
        _fullpath(s, argv[0], _MAX_PATH);
        _splitpath(s,drive,dir,file,ext);
        _makepath(base64_name,drive,dir,"temp",".dat");
        sprintf(base64_name1, "\"%s\"", base64_name);

        _makepath(base64_converter,drive,dir,"BASE64",".exe");

        //convert data to base64 format
        if (spawnl(P_WAIT, base64_converter, base64_converter, "-e", file_name1, base64_name1, NULL)==-1)
        {
                printf("\nError accessing BASE64.exe\n");
                return 1;
        };

        //open data file
        if ((handle = open(base64_name, O_TEXT)) != -1)
        {
                base64_size=filelength(handle);

                /* allocate memory space for upload */
                if ((str = (char *) malloc(base64_size)) == NULL)
                {
                        printf("\nNot enough memory to allocate buffer\n");
                        exit(1);
                };

                //read file into allocated memory(skipping LF)
                index=0;
                do
                {
                        index+=read(handle, &str[index], 72);
                } while (read(handle, temp, 1)==1);

                str[index]=NULL; //create null terminated string

                close(handle);   //close file

                _splitpath(file_name,drive,dir,file,ext);
                strcpy(s, file);
                //generate file name to send to phone
                if (strlen(s)>8)
                {       //if file name greater than 8 truncate to 8
                        strcpy(&s[8], ext);
                } else
                {
                        strcat(s, ext);
                };


                //open connection to WDM
                me.OpenCommPort();

                //send data
                if (me.VNOTE(type, str, file, s, file_size)==1)
                {
                        printf("\nConnection timed out\n");
                        printf("Check phone is connected\n");
                };

                //close connection
                me.CloseCommPort();
                free(str);      //free allocated memory space
        } else
        {
                printf("\nError accessing Base64 file\n");
        };

        //delete temp file
        DeleteFile(base64_name);

        return 0;
}

 